@@ -49,9 +49,8 @@ class WhatsAppChange:
 
 
 class WhatsAppValue:
-    def __init__(self, metadata, contacts=[], errors=[], messaging_product="whatsapp", messages=[], statuses=[]):
+    def __init__(self, metadata, contacts=[], messaging_product="whatsapp", messages=[], statuses=[]):
         self.contacts = [WhatsAppContact(**contact) for contact in contacts]
-        self.errors = [WhatsAppError(**error) for error in errors]
         self.messaging_product = messaging_product
         messages_list = []
         for message in messages:
@@ -71,9 +70,10 @@ class WhatsAppContact:
 
 
 class WhatsAppError:
-    def __init__(self, code, title) -> None:
+    def __init__(self, code, title, href="") -> None:
         self.code = code
         self.title = title
+        self.href = href
 
 
 class WhatsAppMessage:
@@ -120,13 +120,14 @@ class WhatsAppMetadata:
 
 
 class WhatsAppStatus:
-    def __init__(self, id, recipient_id, status, timestamp, conversation=None, pricing=None) -> None:
+    def __init__(self, id, recipient_id, status, timestamp, errors=[], conversation=None, pricing=None) -> None:
         if conversation:
             self.conversation = WhatsAppConversation(**conversation)
         self.id = id
         if pricing:
             self.pricing_category = pricing["category"]
             self.pricing_model = pricing["pricing_model"]
+        self.errors = [WhatsAppError(**error) for error in errors]
         self.recipient_id = recipient_id
         self.status = status
         self.timestamp = timestamp
