@@ -1,18 +1,19 @@
 from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
+from digitalguide.whatsapp.generateActions import Action
 
 def whatsapp_loop_list(client, update: WhatsAppUpdate, context,  key, value, doppelte_antwort):
     if not key in context:
         context[key] = []
 
     if value in context[key]:
-        client.send_message(doppelte_antwort, update.get_from())
+        Action(doppelte_antwort)(client, update, context)
         return "{}_FRAGE".format(key.upper())
     else:
         context[key].append(value)
 
 def whatsapp_loop_list_fertig(client, update: WhatsAppUpdate, context, key, answer_id_list, fertig_antwort):
     if set(answer_id_list).issubset(set(context[key])):
-        client.send_message(fertig_antwort, update.get_from())
+        Action(fertig_antwort)(client, update, context)
 
 def whatsapp_eval_list(client, update: WhatsAppUpdate, context, answer_id_name_list, poi, response_text):
     if not poi in context:
