@@ -41,7 +41,7 @@ def whatsapp_write_photo(client, update: WhatsAppUpdate, context, bucket, folder
 def whatsapp_write_message(client, update: WhatsAppUpdate, context, bucket, folder):
     user_id = update.WaId
     name = update.ProfileName
-    message = update.Body
+    message = update.get_message_text()
 
     s3_client.put_object(Bucket=bucket,
                       Key=folder + "/" +
@@ -74,7 +74,7 @@ def whatsapp_write(client, update: WhatsAppUpdate, context, bucket, folder):
         whatsapp_write_voice(client, update, context, bucket, folder)
     elif update.MediaContentType0 and update.MediaContentType0.startswith("image"):
         whatsapp_write_photo(client, update, context, bucket, folder)
-    elif update.Body != "":
+    elif update.get_message_text() != "":
         whatsapp_write_message(client, update, context, bucket, folder)
     else:
         raise NotImplementedError("This type of update can not be saved")
